"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Schemas = (0, tslib_1.__importStar)(require("./schemas"));
const Utils = (0, tslib_1.__importStar)(require("./utils"));
const Messages = (0, tslib_1.__importStar)(require("./messages"));
/**
 * Class to represent lower-level keys pass fields
 * @see https://apple.co/2wkUBdh
 */
const passInstanceSymbol = Symbol("passInstance");
const sharedKeysPoolSymbol = Symbol("keysPool");
class FieldsArray extends Array {
    constructor(passInstance, keysPool, ...args) {
        super(...args);
        this[passInstanceSymbol] = passInstance;
        this[sharedKeysPoolSymbol] = keysPool;
    }
    push(...items) {
        const validItems = registerWithValidation(this, ...items);
        return super.push(...validItems);
    }
    pop() {
        return unregisterItems(this, () => super.pop());
    }
    splice(start, deleteCount, ...items) {
        // Perfoming frozen check, validation and getting valid items
        const validItems = registerWithValidation(this, ...items);
        for (let i = start; i < start + deleteCount; i++) {
            this[sharedKeysPoolSymbol].delete(this[i].key);
        }
        return super.splice(start, deleteCount, ...validItems);
    }
    shift() {
        return unregisterItems(this, () => super.shift());
    }
    unshift(...items) {
        const validItems = registerWithValidation(this, ...items);
        return super.unshift(...validItems);
    }
}
exports.default = FieldsArray;
function registerWithValidation(instance, ...items) {
    Utils.assertUnfrozen(instance[passInstanceSymbol]);
    let validItems = [];
    for (let i = items.length, field; (field = items[--i]);) {
        try {
            Schemas.assertValidity(Schemas.Field, field, Messages.FIELDS.INVALID);
            if (instance[sharedKeysPoolSymbol].has(field.key)) {
                throw Messages.format(Messages.FIELDS.REPEATED_KEY, field.key);
            }
            instance[sharedKeysPoolSymbol].add(field.key);
            validItems.push(field);
        }
        catch (err) {
            console.warn(err);
        }
    }
    return validItems;
}
function unregisterItems(instance, removeFn) {
    Utils.assertUnfrozen(instance[passInstanceSymbol]);
    const element = removeFn();
    instance[sharedKeysPoolSymbol].delete(element.key);
    return element;
}
//# sourceMappingURL=FieldsArray.js.map